
Overview
========

grappelli_safe was created to provide a snapshot of the 
`Grappelli admin skin <http://code.google.com/p/django-grappelli/>`_ for 
`Django <http://www.djangoproject.com/>`_, to be referenced as a 
dependency for the `Mezzanine CMS for Django <http://mezzanine.jupo.org/>`_.

At the time of grappelli_safe's creation, Grappelli was incorrectly 
packaged on `PyPI <http://pypi.python.org/pypi>`_, and had also dropped 
compatibility with Django 1.1 - grappelli_safe was therefore created to 
address these specific issues.

This repository exists for bug fixes and minor enhancements, and 
should some day become redundant, once the original Grappelli becomes 
a feasibly stable dependency target.
